@@ -554,6 +554,21 @@ class NodesTest(base.TestCase):
                                                    properties=node_properties,
                                                    driver_info={})
 
+    def test_register_ironic_node_pxe_ucs(self):
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6"}
+        node = self._get_node()
+        node['pm_type'] = 'pxe_ucs'
+        client = mock.MagicMock()
+        nodes.register_ironic_node(node, client=client)
+        client.node.create.assert_called_once_with(
+            driver='pxe_ucs', name='node1', properties=node_properties,
+            driver_info={'ucs_password': 'random', 'ucs_address': 'foo.bar',
+                         'ucs_username': 'test'})
+
     def test_register_ironic_node_update_int_values(self):
         node = self._get_node()
         ironic = mock.MagicMock()
