@@ -16,10 +16,12 @@ import base64
 import logging
 import os
 import struct
-import subprocess
 import time
+import uuid
 
 import passlib.utils as passutils
+import six
+
 from tripleo_common import constants
 
 
@@ -27,27 +29,31 @@ _MIN_PASSWORD_SIZE = 25
 LOG = logging.getLogger(__name__)
 
 
-def generate_overcloud_passwords():
+def generate_overcloud_passwords(mistralclient, stack_env=None):
     """Create the passwords needed for the overcloud
 
     This will create the set of passwords required by the overcloud, store
-    them in the output file path and return a dictionary of passwords. If the
-    file already exists the existing passwords will be returned instead,
+    them in the output file path and return a dictionary of passwords.
     """
 
     passwords = {}
 
     for name in constants.PASSWORD_PARAMETER_NAMES:
-        # CephX keys aren't random strings
-        if name.startswith("Ceph"):
-            passwords[name] = create_cephx_key()
+
+        # Support users upgrading from Mitaka or otherwise creating a plan for
+        # a Heat stack that already exists.
+        if stack_env and name in stack_env.get('parameter_defaults', {}):
+            passwords[name] = stack_env['parameter_defaults'][name]
+        elif name.startswith("Ceph"):
+            if name == "CephClusterFSID":
+                # The FSID must be a UUID
+                passwords[name] = six.text_type(uuid.uuid1())
+            else:
+                # CephX keys aren't random strings
+                passwords[name] = create_cephx_key()
+        # The SnmpdReadonlyUserPassword is stored in a mistral env.
         elif name == 'SnmpdReadonlyUserPassword':
-            snmp_password = get_hiera_key(
-                'snmpd_readonly_user_password')
-            passwords[name] = snmp_password
-            if not snmp_password:
-                LOG.warning("Undercloud ceilometer SNMPd password "
-                            "missing!")
+            passwords[name] = get_snmpd_readonly_user_password(mistralclient)
         elif name in ('KeystoneCredential0', 'KeystoneCredential1'):
             passwords[name] = create_keystone_credential()
         else:
@@ -64,17 +70,13 @@ def create_cephx_key():
     return base64.b64encode(header + key)
 
 
-def get_hiera_key(key_name):
-    """Retrieve a key from the hiera store
-
-    :param password_name: Name of the key to retrieve
-    :type  password_name: type
-    """
-
-    command = ["hiera", key_name]
-    p = subprocess.Popen(command, stdout=subprocess.PIPE)
-    out, err = p.communicate()
-    return out
+def get_snmpd_readonly_user_password(mistralclient):
+    mistral_env = mistralclient.environments.get("tripleo.undercloud-config")
+    try:
+        return mistral_env.variables['undercloud_ceilometer_snmpd_password']
+    except KeyError:
+        LOG.error("Undercloud ceilometer SNMPd password missing!")
+        raise
 
 
 def create_keystone_credential():
